@@ -2,8 +2,8 @@ from .simple import StringField
 
 
 class EmailField(StringField):
-    def prepare_value(self, value):
-        value = super().prepare_value(value)
+    def prepare_value(self, document, value):
+        value = super().prepare_value(document, value)
 
         if value is not None:
             if '@' not in value:
